function y = cropx8(x)
% CROPX8 crops the image to a size being multiples of 8 for IPOL online demo.
%
%   SYNTAX:
%     y = cropx8(x);
%
%   INPUT: 
%     x     - original image
%
%   OUTPUT:
%     y     - cropped image
%
% IPOL SUBMISSION "Spectral Pre-Adaptation for Restoring Real-World Blurred 
% Images Using Standard Deconvolution Methods"
%
% Version 1.2, June 2022
%
% Copyright (c) 2022
% Javier Portilla <javier.portilla@csic.es>
% Chaoqun Dong <chaodong999@gmail.com>
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as
% published by the Free Software Foundation, either version 3 of the
% License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.
% make sure the kernel is normalized


Nmul = 8;
[Ny,Nx] = size(x);
ry = rem(Ny,Nmul); rx = rem(Nx,Nmul);
y = x(1:end-ry,1:end-rx);


