function [Ley, Lex] = get_extra_size_2(kernel, Ny, Nx)
% GET_EXTRA_SIZE computes the extra boundary extension size for IPOL online demo.
%
%   SYNTAX:
%     [Ley, Lex] = get_extra_size(kernel, Ny, Nx);
%
%   INPUT: 
%     kernel     - the blurring kernel
%     Ny, Nx     - size of the blurred observation
%
%   OUTPUT:
%     Ley, Lex   - extra extension size along y and x direction
%
% IPOL SUBMISSION "Spectral Pre-Adaptation for Restoring Real-World Blurred 
% Images Using Standard Deconvolution Methods"
%
% Version 1.2, June 2022
%
% Copyright (c) 2022
% Javier Portilla <javier.portilla@csic.es>
% Chaoqun Dong <chaodong999@gmail.com>
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as
% published by the Free Software Foundation, either version 3 of the
% License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.
% make sure the kernel is normalized

kernel = kernel/sum(sum(kernel));
[ny,nx] = size(kernel);  % in our implementation the kernel size should be odd for both dimensions

C_kernel = kernel'*kernel;
D_kk = eig(C_kernel);
Le_min = 0;   % minimum extension size

if numel(D_kk)==1 || D_kk(end-1)/D_kk(end) < 1e-4,
    separable = true;
else
    separable= false;
end

Nmul = 8;

if separable % the final size multiple of (ny,nx) and of Nmul
        Ley = ((ceil(Ny/(ny*Nmul)))*(ny*Nmul)-Ny);
        Lex = ((ceil(Nx/(nx*Nmul)))*(nx*Nmul)-Nx);
        Ley = Ley/2;
        Lex = Lex/2;
else
    % for non-separable kernels, just multiple of Nmul
        Ley = ((ceil(Ny/(Nmul)))*(Nmul)-Ny);
        Lex = ((ceil(Nx/(Nmul)))*(Nmul)-Nx);
        Ley = Ley/2;
        Lex = Lex/2;
end
