function PX_f = get_x_psd(im_range, Ny, Nx)
% GET_X_PSD computes the PSD of the uncorrupted image x.
%
% IPOL SUBMISSION "Spectral Pre-Adaptation for Restoring Real-World Blurred 
% Images Using Standard Deconvolution Methods"
%
% Version 1.2, June 2022
%
% Copyright (c) 2022
% Javier Portilla <javier.portilla@csic.es>
% Chaoqun Dong <chaodong999@gmail.com>
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as
% published by the Free Software Foundation, either version 3 of the
% License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.


% sigma_x and rho (adapted to the [0 255] range) work well for Wiener
% (both boundary processing and Wiener "optimized" at the same time).
sigma_x = 30*im_range/256;       % convert default sigma_x to other image range
sig2x = sigma_x^2;
rho = 0.65;

[xc, yc] = meshgrid(1:Nx,1:Ny);
xc = xc - 1 - Nx/2;
yc = yc - 1 - Ny/2;
u = xc/Nx;
v = yc/Ny;
PX_f = sig2x*4*log(rho)^2./((log(rho)^2 + 4*pi^2*u.^2).*(log(rho)^2 + 4*pi^2*v.^2));
PX_f = fftshift(PX_f);
